@echo off

rem	GAMS Scenario Interface SubProgram -- solve.bat
rem	Thomas F. Rutherford
rem	February, 2001

rem	This batch command file can be used to define and solve 
rem	scenarios for GAMS models using the GAMS-SM package.

rem	Command syntax for defining and solving a scenario:

rem		solve [modelfile] scenario [input1=value1 [input2=value2 ...]]

rem	where modelfile.gms contains the model file with inputs identifiers as 
rem	setglobal parameters.

rem	When modelfile.gms is not found, model.gms is assumed.

rem	Resolve all existing cases for a model by typing:

rem		solve [modelfile] /all

if "%1"=="" goto syntax

set modelfile=model
if not exist %1.gms goto checkmodel
if exist scenarios\%1 goto ambiguous
set modelfile=%1
echo    modelfile is %1
shift

:checkmodel
if not exist %modelfile%.gms goto nomodel

rem	Create a output and scenarios subdirectories 
rem	if they do not exist:

if not exist output\nul mkdir output
if not exist scenarios\nul mkdir scenarios

rem	Solve all cases?

if %1==/all goto solveall
if %1==/ALL goto solveall

rem	Retrieve the scenario file:

:	Skip cases which have been solved:

if exist output\%1.sol goto end

set scenario=%1
echo    scenario is %1
shift
if "%1"=="" goto runbare

echo	$ontext	>scenarios\%scenario%
date /t <nul	>>scenarios\%scenario%
time /t <nul	>>scenarios\%scenario%
echo	$offtext >>scenarios\%scenario%

rem	Loop to assign input values:

:nextinput
if "%1"=="" goto run
if not "%2"=="" goto setglobal
echo.
echo	Error -- cannot find assigned value for input: %1
echo.
echo	Scenario file written thus far is:
echo.
if exist scenarios\%scenario% type scenarios\%scenario%
echo.
pause
goto syntax

:setglobal
echo	$setglobal %1 %2	>>scenarios\%scenario%
shift
shift
goto nextinput

:runbare
if exist scenarios\%scenario% goto run

echo	$ontext	>scenarios\%scenario%
date /t <nul	>>scenarios\%scenario%
time /t	<nul	>>scenarios\%scenario%
echo	$offtext >>scenarios\%scenario%

:run
if exist scenarios\%scenario% goto start
echo.
echo	Error -- scenario file not found: scenarios\%scenario%
echo.
pause
goto syntax

:start
title	Running scenario %scenario%
echo	$include scenarios\%scenario%	>output\%scenario%.gms
echo	$setglobal scenario %scenario%	>>output\%scenario%.gms
echo	$include %modelfile%	>>output\%scenario%.gms
if     exist inclib\nul call gams output\%scenario%.gms o=output\%scenario%.lst relpath=1 ldir=.\inclib
if not exist inclib\nul call gams output\%scenario%.gms o=output\%scenario%.lst 
goto end

rem	Requested to solve all cases -- generate a batch 
rem	file to solve each of the cases:

:solveall
echo	@echo off	>output\solves.bat
cd scenarios
for %%f in (*.*) do echo call solve %%f >>..\output\solves.bat
cd ..
output\solves

:nomodel
echo.
echo	Input error: I cannot file %1.gms nor model.gms
echo.
echo	Model file must be specified as first argument to this
echo	script, or the model file must be named "model.gms".
echo.
pause
goto syntax

:ambiguous
echo.
echo	Input error:  I find both files, %1.gms and scenarios\%1.
echo.
echo	You must delete %1.gms if you want to define a scenario named %1
echo.
goto end

:syntax
echo.
echo	Command syntax for solving a scenario:
echo.
echo		solve [modelfile] scenario [input1=value1 [input2=value2 ...]]
echo.
echo	where modelfile.gms contains the model file with inputs identifiers as 
echo	setglobal parameters.
echo.
echo	When modelfile.gms is not found, model.gms is assumed.
echo.
echo	Resolve all existing cases for a model by typing:
echo.
echo		solve [modelfile] /all
echo.

:end
